@@ -82,14 +82,14 @@ plot_grid(
   labels = "AUTO"
 )
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  library("glmmTMB")
 #  tmb <- glmmTMB(count~spp * mined + (1|site),
 #                ziformula = ~spp * mined,
 #                family=nbinom2, Salamanders)
 #  
 
-## ---- eval=FALSE, include=FALSE---------------------------------------------------------
+## ----eval=FALSE, include=FALSE----------------------------------------------------------
 #  library("glmmTMB")
 #  set_sum_contrasts()
 #  tmb <- glmmTMB(count~spp * mined + (1|site),
@@ -97,7 +97,7 @@ plot_grid(
 #                family=nbinom2, Salamanders)
 #  save(tmb, file = "inst/extdata/tmb_example_fit.rda", compress = "xz")
 
-## ---- echo=FALSE, include=FALSE---------------------------------------------------------
+## ----echo=FALSE, include=FALSE----------------------------------------------------------
 library("glmmTMB")
 data(Salamanders, package = "glmmTMB")
 load(system.file("extdata/", "tmb_example_fit.rda", package = "afex"))
@@ -130,7 +130,7 @@ afex_plot(tmb, "spp", "mined", id = "site", data = Salamanders,
                           color = "darkgrey")
           )
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  library("rstanarm") ## requires resetting the ggplot2 theme
 #  theme_set(theme_bw(base_size = 14) +
 #              theme(legend.position="bottom",
@@ -142,7 +142,7 @@ afex_plot(tmb, "spp", "mined", id = "site", data = Salamanders,
 #                              data = cbpp, family = binomial, weight = size,
 #                              chains = 2, cores = 1, seed = 12345, iter = 500)
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  b1 <- afex_plot(example_model, "period")
 #  ## dv column detected: prob
 #  ## No id column passed. Assuming all rows are independent samples.
@@ -153,9 +153,9 @@ afex_plot(tmb, "spp", "mined", id = "site", data = Salamanders,
 
 ## ----fig.width=7, fig.height=3, echo=FALSE----------------------------------------------
 load(system.file("extdata/", "plots_rstanarm.rda", package = "afex"))
-plot_grid(b1, b2, labels = "AUTO")
+grid::grid.newpage(); grid::grid.draw(b12)
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  cbpp_l <- vector("list", nrow(cbpp))
 #  for (i in seq_along(cbpp_l)) {
 #    cbpp_l[[i]] <- data.frame(
@@ -172,7 +172,7 @@ plot_grid(b1, b2, labels = "AUTO")
 #                               data = cbpp_l, family = binomial,
 #                               chains = 2, cores = 1, seed = 12345, iter = 500)
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  b3 <- afex_plot(example_model2, "period")
 #  ## dv column detected: incidence
 #  ## No id column passed. Assuming all rows are independent samples.
@@ -181,14 +181,14 @@ plot_grid(b1, b2, labels = "AUTO")
 #  plot_grid(b3, b4, labels = "AUTO")
 
 ## ----fig.width=7, fig.height=3, echo=FALSE----------------------------------------------
-plot_grid(b3, b4, labels = "AUTO")
+grid::grid.newpage(); grid::grid.draw(b34)
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  data("Machines", package = "MEMSS")
 #  mm <- stan_lmer(score ~ Machine + (Machine|Worker), data=Machines,
 #                  chains = 2, cores = 1, seed = 12345, iter = 500)
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  b5 <- afex_plot(mm, "Machine")
 #  ## dv column detected: score
 #  ## No id column passed. Assuming all rows are independent samples.
@@ -197,9 +197,9 @@ plot_grid(b3, b4, labels = "AUTO")
 #  plot_grid(b5, b6, labels = "AUTO")
 
 ## ----fig.width=7, fig.height=3, echo=FALSE----------------------------------------------
-plot_grid(b5, b6, labels = "AUTO")
+grid::grid.newpage(); grid::grid.draw(b56)
 
-## ---- eval=FALSE, include=FALSE---------------------------------------------------------
+## ----eval=FALSE, include=FALSE----------------------------------------------------------
 #  library("rstanarm") ## requires resetting the ggplot2 theme
 #  library("ggplot2")
 #  theme_set(theme_bw(base_size = 14) +
@@ -214,6 +214,7 @@ plot_grid(b5, b6, labels = "AUTO")
 #                              chains = 2, cores = 1, seed = 12345, iter = 500)
 #  b1 <- afex_plot(example_model, "period")
 #  b2 <- afex_plot(example_model, "period", data_geom = geom_violin)
+#  b12 <- ggplotGrob(plot_grid(b1, b2))
 #  
 #  cbpp_l <- vector("list", nrow(cbpp))
 #  for (i in seq_along(cbpp_l)) {
@@ -232,22 +233,24 @@ plot_grid(b5, b6, labels = "AUTO")
 #                               chains = 2, cores = 1, seed = 12345, iter = 500)
 #  b3 <- afex_plot(example_model2, "period")
 #  b4 <- afex_plot(example_model2, "period", id = "herd")
+#  b34 <- plot_grid(b3, b4)
 #  
 #  data("Machines", package = "MEMSS")
 #  mm <- stan_lmer(score ~ Machine + (Machine|Worker), data=Machines,
 #                  chains = 2, cores = 1, seed = 12345, iter = 500)
 #  b5 <- afex_plot(mm, "Machine")
 #  b6 <- afex_plot(mm, "Machine", id = "Worker", data = Machines)
-#  save(b1, b2, b3, b4, b5, b6, file = "../inst/extdata/plots_rstanarm.rda",
+#  b56 <- ggplotGrob(plot_grid(b5, b6))
+#  save(b12, b34, b56, file = "../inst/extdata/plots_rstanarm.rda",
 #       compress = "xz", version = 2)
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  library("brms")
 #  data("Machines", package = "MEMSS")
 #  mm2 <- brm(score ~ Machine + (Machine|Worker), data=Machines,
 #             chains = 2, cores = 1, seed = 12345, iter = 500)
 
-## ---- eval=FALSE------------------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------------------------------------
 #  bb1 <- afex_plot(mm2, "Machine", data = Machines, dv = "score")
 #  ## No id column passed. Assuming all rows are independent samples.
 #  bb2 <- afex_plot(mm2, "Machine", id = "Worker",
@@ -256,9 +259,9 @@ plot_grid(b5, b6, labels = "AUTO")
 
 ## ----fig.width=7, fig.height=3, echo=FALSE----------------------------------------------
 load(system.file("extdata/", "plots_brms.rda", package = "afex"))
-plot_grid(bb1, bb2)
+grid::grid.newpage(); grid::grid.draw(bbout)
 
-## ---- eval=FALSE, include=FALSE---------------------------------------------------------
+## ----eval=FALSE, include=FALSE----------------------------------------------------------
 #  library("brms")
 #  data("Machines", package = "MEMSS")
 #  mm2 <- brm(score ~ Machine + (Machine|Worker), data=Machines,
@@ -266,7 +269,8 @@ plot_grid(bb1, bb2)
 #  bb1 <- afex_plot(mm2, "Machine", data = Machines, dv = "score")
 #  bb2 <- afex_plot(mm2, "Machine", id = "Worker",
 #            data = Machines, dv = "score")
-#  save(bb1, bb2, file = "../inst/extdata/plots_brms.rda", version = 2)
+#  bbout <- ggplotGrob(plot_grid(bb1, bb2))
+#  save(bbout, file = "../inst/extdata/plots_brms.rda", version = 2)
 
 ## ----fig.width=4, fig.height=3, eval = FALSE--------------------------------------------
 #  library("GLMMadaptive")
